@@ -1,6 +1,6 @@
 use strict; use warnings;
 package XXX;
-our $VERSION = '0.28';
+our $VERSION = '0.30';
 use base 'Exporter';
 
 our @EXPORT = qw( WWW XXX YYY ZZZ );
@@ -17,7 +17,7 @@ sub import {
             $DumpModule = $args[$i];
             die "Don't know how to use XXX -with '$DumpModule'"
                 unless $DumpModule =~ /^(
-                                           YAML|
+                                           (?:YAML|JSON)(?:::.*)?|
                                            Data::Dumper|
                                            Data::Dump(?:::Color)?
                                        )$/x;
@@ -45,6 +45,7 @@ sub _xxx_dump {
     $DumpModule ||= 'YAML';
     my $dump_type =
         ($DumpModule =~ /^YAML/) ? 'yaml' :
+        ($DumpModule =~ /^JSON/) ? 'json' :
         ($DumpModule eq 'Data::Dumper') ? 'dumper' :
         ($DumpModule eq 'Data::Dump') ? 'dump' :
         ($DumpModule eq 'Data::Dump::Color') ? 'dumpcolor' :
@@ -55,6 +56,9 @@ sub _xxx_dump {
     if ($dump_type eq 'yaml') {
         return &{"$DumpModule\::Dump"}(@_) . "...\n";
     }
+    elsif ($dump_type eq 'json') {
+        return &{"$DumpModule\::encode_json"}(@_);
+    }
     elsif ($dump_type eq 'dumper') {
         local $Data::Dumper::Sortkeys = 1;
         local $Data::Dumper::Indent = 2;
